#include <libssc-sensor.h>
#include <libssc-sensor-accelerometer.h>

int
main (int    argc,
      char **argv)
{
  SSCSensorAccelerometer *sensor = ssc_sensor_accelerometer_new_sync (NULL, NULL);
  ssc_sensor_accelerometer_close_sync (sensor, NULL, NULL);
}
